@@ -1,15 +1,15 @@
-#line 19 "columns.nw"
-static char rcsid[] = "$Id: columns.nw,v 2.9 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+#line 18 "columns.nw"
+static char rcsid[] = "$Id: columns.nw,v 2.21 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdio.h>
 #include "columns.h"
 
 int tabsize = 8;
-#line 26 "columns.nw"
+#line 25 "columns.nw"
 int columnwidth (char *s) {             /* width of a string in columns */
   return limitcolumn(s, 0);
 }
-#line 31 "columns.nw"
+#line 29 "columns.nw"
 int limitcolumn (char *s, int col) {
     while (*s) {
         col++;
@@ -18,7 +18,7 @@ int limitcolumn (char *s, int col) {
     }
     return col;
 }
-#line 41 "columns.nw"
+#line 38 "columns.nw"
 void indent_for (int width, FILE *fp) { 
                                 /* write whitespace [[width]] columns wide */
 /*fprintf(fp,"<%2d>",width); if (width>4) {fprintf(fp,"    "); width -= 4;}*/
@@ -32,3 +32,4 @@ void indent_for (int width, FILE *fp) {
         width--;
     }
 }
+
