@@ -1,6 +1,6 @@
 #line 5 "finduses.nw"
-static char rcsid[] = "$Id: finduses.nw,v 1.7 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: finduses.nw,v 1.19 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -25,7 +25,7 @@ typedef struct line_and_outfile {
 static void read_ids(FILE *in);
 #line 100 "finduses.nw"
 static void add_use_markers(FILE *in, FILE *out);
-#line 153 "finduses.nw"
+#line 152 "finduses.nw"
 static void write_index_use(void *closure, char *id, char *instance);
 static char *emit_up_to(FILE *f, char *s, char *limit);
 #line 33 "finduses.nw"
@@ -46,12 +46,12 @@ main(int argc, char **argv) {
 {   FILE *tmp = tmpfile();
     char *line;
     if (tmp == NULL) 
-#line 156 "finduses.nw"
+#line 155 "finduses.nw"
 errormsg(Fatal, "%s: couldn't open temporary file\n", progname);
 #line 78 "finduses.nw"
     while ((line = getline(stdin)) != NULL) {
         if (fputs(line, tmp) == EOF) 
-#line 158 "finduses.nw"
+#line 157 "finduses.nw"
 errormsg(Fatal, "%s: error writing temporary file\n", progname);
 #line 80 "finduses.nw"
         if (is_index(line, "defn")) {
@@ -121,7 +121,7 @@ static void write_index_use(void *closure, char *id, char *instance) {
   fprintf(info->out, "@index use %s\n", id);
   info->line = emit_up_to(info->out, info->line, instance + strlen(id));
 }
-#line 141 "finduses.nw"
+#line 140 "finduses.nw"
 static char *emit_up_to(FILE *f, char *s, char *limit) {
   if (s < limit) {
     char saved = *limit;
