@@ -1,6 +1,6 @@
 #line 17 "getline.nw"
-static char rcsid[] = "$Id: getline.nw,v 2.9 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: getline.nw,v 2.21 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #define START_SIZE 128                  /* initial buffer size */
 
 #include <stdio.h>
@@ -22,7 +22,7 @@ void new_buffers(void) {
 char *getline (FILE *fp) {
 
     
-#line 84 "getline.nw"
+#line 82 "getline.nw"
 if (buf1==NULL) {
     checkptr(buf1 = (char *) malloc (buf_size));
     checkptr(buf2 = (char *) malloc (buf_size));
@@ -39,19 +39,19 @@ if (buf1==NULL) {
     }
     return buf1;
 }
-#line 63 "getline.nw"
+#line 62 "getline.nw"
 char *getline_expand (FILE *fp) {
     char *s, *t;
     int width;
 
     if (getline(fp)==NULL) return NULL;
     
-#line 89 "getline.nw"
+#line 87 "getline.nw"
 if (columnwidth(buf1) > buf_size - 1) {
     while (columnwidth(buf1) > buf_size - 1) buf_size *= 2;
     new_buffers();
 }
-#line 69 "getline.nw"
+#line 68 "getline.nw"
     s = buf1; t = buf2; width=0;
     while (*s)
         if (*s=='\t' && tabsize > 0) {
