@@ -1,6 +1,6 @@
 #line 7 "main.nw"
-static char rcsid[] = "$Id: main.nw,v 2.10 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: main.nw,v 2.22 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
