@@ -1,6 +1,6 @@
-#line 67 "markmain.nw"
-static char rcsid[] = "$Id: markmain.nw,v 2.14 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+#line 66 "markmain.nw"
+static char rcsid[] = "$Id: markmain.nw,v 2.26 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -43,7 +43,7 @@ static void print_pair(FILE *out, char *name, char *value) {
         fprintf(out, "%c%s\n", low_at_sign, name);
 }
 
-#line 81 "markmain.nw"
+#line 80 "markmain.nw"
 void markup (FILE* in, FILE *out, char *filename) {
     State state = Docs;         /* what we are reading */
     int quoting = 0;            /* currently quoting code? */
@@ -59,23 +59,23 @@ void markup (FILE* in, FILE *out, char *filename) {
                                          [[""]] if no module is being read */ 
 
     
-#line 122 "markmain.nw"
+#line 121 "markmain.nw"
 print_pair(out, "file", filename);
 print_state(out, Begin, state, count);
 while ((line = getline_expand(in)) != NULL) {
     lineno++;
     
-#line 173 "markmain.nw"
+#line 172 "markmain.nw"
 missing_newline = line[strlen(line)-1] != '\n';
-#line 127 "markmain.nw"
+#line 126 "markmain.nw"
     if (starts_code(line, filename, lineno)) {
         
-#line 543 "markmain.nw"
+#line 542 "markmain.nw"
 if (quoting) {
     errorat(filename, last_open_quote, Warning, "open quote `[[' never closed");
     quoting = 0;
 }
-#line 129 "markmain.nw"
+#line 128 "markmain.nw"
         print_state(out, End, state, count);
         count++;
         state = Code;
@@ -85,7 +85,7 @@ if (quoting) {
         print_pair(out,"nl",0);     /* could be implicit but this is better */
     } else if (is_def(line)) {
         
-#line 529 "markmain.nw"
+#line 528 "markmain.nw"
 line = remove_def_marker(line);
 while (*line && isspace(*line)) line++;
 while (*line) {
@@ -99,18 +99,18 @@ while (*line) {
   line = s;
 }
 print_index(out, Newline, 0);
-#line 138 "markmain.nw"
+#line 137 "markmain.nw"
         if (state == Code)
             state = CodeIndex;
     } else {
         if (starts_doc(line) || state == CodeIndex) {
             
-#line 543 "markmain.nw"
+#line 542 "markmain.nw"
 if (quoting) {
     errorat(filename, last_open_quote, Warning, "open quote `[[' never closed");
     quoting = 0;
 }
-#line 143 "markmain.nw"
+#line 142 "markmain.nw"
             print_state(out, End, state, count);
             count++;
             state = Docs;       /* always reading docs after a stop */
@@ -119,13 +119,13 @@ if (quoting) {
                 line = first_doc_line(line);
         }
         {   
-#line 182 "markmain.nw"
+#line 181 "markmain.nw"
 char *p, *s, *t, c;
 static char *buf;
 static int buflen = 0;
-#line 151 "markmain.nw"
+#line 150 "markmain.nw"
             
-#line 260 "markmain.nw"
+#line 259 "markmain.nw"
 #define LA1 '<'
 #define LA2 '<'
 #define RA1 '>'
@@ -135,14 +135,14 @@ static int buflen = 0;
 #define RS1 ']'
 #define RS2 ']'
 #define ESC '@'
-#line 273 "markmain.nw"
+#line 272 "markmain.nw"
 #define next(L) do {           c = *t++; goto L; } while (0)
 #define copy(L) do { *s++ = c; c = *t++; goto L; } while (0)
-#line 279 "markmain.nw"
+#line 278 "markmain.nw"
 #define lexassert(E) ((void)0)
-#line 152 "markmain.nw"
+#line 151 "markmain.nw"
             
-#line 506 "markmain.nw"
+#line 505 "markmain.nw"
 if (buf == NULL)
   checkptr(buf = (char *) malloc(buflen = 128));
 if (buflen < strlen(line) + 1 + 2) {
@@ -150,221 +150,221 @@ if (buflen < strlen(line) + 1 + 2) {
     buflen *= 2;
   checkptr(buf = (char *) realloc(buf, buflen));
 }
-#line 187 "markmain.nw"
+#line 186 "markmain.nw"
 p = s = buf+2;
 t = line;
 c = *t++;
-#line 153 "markmain.nw"
+#line 152 "markmain.nw"
             
-#line 207 "markmain.nw"
+#line 206 "markmain.nw"
 if (c == ESC && *t == ESC) { *s++ = ESC; c = *++t; ++t; }
-#line 154 "markmain.nw"
+#line 153 "markmain.nw"
             if (state == Code || quoting) 
                 goto convert_code;
             else
                 goto convert_docs;
             
-#line 297 "markmain.nw"
+#line 296 "markmain.nw"
 convert_docs:
 t: lexassert(state == Docs && !quoting);
    if (c == ESC) next(at);
    if (c == LA1) next(la);
    if (c == LS1) next(ls);
    
-#line 243 "markmain.nw"
+#line 242 "markmain.nw"
 if (c == '\0') {
   
-#line 514 "markmain.nw"
+#line 513 "markmain.nw"
 if (s > p) {
   *s = 0;
   print_pair(out, "text", p);
 }
 s = p = buf + 2;
-#line 245 "markmain.nw"
+#line 244 "markmain.nw"
   goto done_converting;
 }
-#line 303 "markmain.nw"
+#line 302 "markmain.nw"
    copy(t);
-#line 311 "markmain.nw"
+#line 310 "markmain.nw"
 at: if (c == LA1) next(atla);
     if (c == LS1) next(atls);
     if (c == RA1) next(atra);
     if (c == RS1) next(atrs);
     *s++ = ESC; goto t;
-#line 320 "markmain.nw"
+#line 319 "markmain.nw"
 atls: if (c == LS2) { *s++ = LS1; *s++ = LS2; next(t); }
      *s++ = ESC; *s++ = LS1; goto t;
-#line 326 "markmain.nw"
+#line 325 "markmain.nw"
 atla: if (c == LA2) { *s++ = LA1; *s++ = LA2; next(t); }
       *s++ = ESC; *s++ = LA1; goto t;
-#line 332 "markmain.nw"
+#line 331 "markmain.nw"
 atrs: if (c == RS2) { *s++ = RS1; *s++ = RS2; next(t); }
      *s++ = ESC; *s++ = RS1; goto t;
-#line 338 "markmain.nw"
+#line 337 "markmain.nw"
 atra: if (c == RA2) { *s++ = RA1; *s++ = RA2; next(t); }
       *s++ = ESC; *s++ = RA1; goto t;
-#line 344 "markmain.nw"
+#line 343 "markmain.nw"
 la: if (c == LA2) {
       
-#line 526 "markmain.nw"
+#line 525 "markmain.nw"
 errorat(filename, lineno, Error, "unescaped << in documentation chunk");
-#line 346 "markmain.nw"
+#line 345 "markmain.nw"
       *s++ = LA1; *s++ = LA2; next(t);
     }
     *s++ = LA1; goto t;
-#line 356 "markmain.nw"
+#line 355 "markmain.nw"
 ls: lexassert(state == Docs);
     if (c == LS2) {
       
-#line 514 "markmain.nw"
+#line 513 "markmain.nw"
 if (s > p) {
   *s = 0;
   print_pair(out, "text", p);
 }
 s = p = buf + 2;
-#line 359 "markmain.nw"
+#line 358 "markmain.nw"
       quoting = 1; last_open_quote = lineno; print_pair(out, "quote", 0); 
       next(c);
     }
     *s++ = LS1;
     goto t;
-#line 373 "markmain.nw"
+#line 372 "markmain.nw"
 convert_code:
 c: lexassert(state == Code || quoting);
    if (c == RS1 && quoting) next(crs);
    if (c == LA1) next(cla);
    if (c == ESC) next(cat);
    
-#line 243 "markmain.nw"
+#line 242 "markmain.nw"
 if (c == '\0') {
   
-#line 514 "markmain.nw"
+#line 513 "markmain.nw"
 if (s > p) {
   *s = 0;
   print_pair(out, "text", p);
 }
 s = p = buf + 2;
-#line 245 "markmain.nw"
+#line 244 "markmain.nw"
   goto done_converting;
 }
-#line 379 "markmain.nw"
+#line 378 "markmain.nw"
    copy(c);
-#line 387 "markmain.nw"
+#line 386 "markmain.nw"
 cat: if (c == LA1) next(catla);
      if (c == RA1) next(catra);
      *s++ = ESC; goto c;
-#line 394 "markmain.nw"
+#line 393 "markmain.nw"
 catla: if (c == LA2) { *s++ = LA1; *s++ = LA2; next(c); }
        *s++ = ESC; *s++ = LA1; goto c;
-#line 400 "markmain.nw"
+#line 399 "markmain.nw"
 catra: if (c == RA2) { *s++ = RA1; *s++ = RA2; next(c); }
        *s++ = ESC; *s++ = RA1; goto c;
-#line 408 "markmain.nw"
+#line 407 "markmain.nw"
 crs: if (c == RS2) next(ce);
      *s++ = RS1; goto c;
-#line 414 "markmain.nw"
+#line 413 "markmain.nw"
 ce: lexassert(quoting);
     if (c == RS2) copy(ce);
     quoting = 0; 
-#line 514 "markmain.nw"
+#line 513 "markmain.nw"
 if (s > p) {
   *s = 0;
   print_pair(out, "text", p);
 }
 s = p = buf + 2;
-#line 416 "markmain.nw"
+#line 415 "markmain.nw"
                                                  print_pair(out, "endquote", 0);
     goto t;
-#line 424 "markmain.nw"
+#line 423 "markmain.nw"
 cla: if (c == LA2) { 
-#line 514 "markmain.nw"
+#line 513 "markmain.nw"
 if (s > p) {
   *s = 0;
   print_pair(out, "text", p);
 }
 s = p = buf + 2;
-#line 424 "markmain.nw"
+#line 423 "markmain.nw"
                                                      next(u); }
      *s++ = LA1; goto c;
-#line 435 "markmain.nw"
+#line 434 "markmain.nw"
 u: lexassert(state == Code || quoting);
    if (c == LS1) copy(uls);
    if (c == RS1 && quoting) next(urs);
    if (c == RA1) next(ura);
    if (c == '\0') { /* premature end --- it's not a use after all */
      
-#line 501 "markmain.nw"
+#line 500 "markmain.nw"
 lexassert(p == buf + 2);
 p -= 2;
 p[0] = LA1;
 p[1] = LA2;
-#line 441 "markmain.nw"
+#line 440 "markmain.nw"
      goto c;
    }
    copy(u);
-#line 448 "markmain.nw"
+#line 447 "markmain.nw"
 urs: lexassert(quoting);
      if (c == RS2) { /* premature end --- it's not a use after all */
        
-#line 501 "markmain.nw"
+#line 500 "markmain.nw"
 lexassert(p == buf + 2);
 p -= 2;
 p[0] = LA1;
 p[1] = LA2;
-#line 451 "markmain.nw"
+#line 450 "markmain.nw"
        next(ce); 
      }
      *s++ = RS1; goto u;
-#line 458 "markmain.nw"
+#line 457 "markmain.nw"
 uls: if (c == LS2) copy(uc);
      goto u;
-#line 465 "markmain.nw"
+#line 464 "markmain.nw"
 uc: lexassert(quoting || state == Code);
     if (c == RS1) copy(ucrs);
     if (c == '\0') {
       
-#line 501 "markmain.nw"
+#line 500 "markmain.nw"
 lexassert(p == buf + 2);
 p -= 2;
 p[0] = LA1;
 p[1] = LA2;
-#line 469 "markmain.nw"
+#line 468 "markmain.nw"
       goto c;
     }
     copy(uc);
-#line 476 "markmain.nw"
+#line 475 "markmain.nw"
 ucrs: if (c == RS2) copy(uce);
       goto uc;
-#line 482 "markmain.nw"
+#line 481 "markmain.nw"
 uce: if (c == RS2) copy(uce);
      goto u;
-#line 488 "markmain.nw"
+#line 487 "markmain.nw"
 ura: if (c == RA2) { 
-#line 521 "markmain.nw"
+#line 520 "markmain.nw"
 *s = 0;
 print_pair(out, "use", p);
 s = p = buf + 2;
-#line 488 "markmain.nw"
+#line 487 "markmain.nw"
                                                     next(c); }
      *s++ = RA1; goto u;
-#line 159 "markmain.nw"
+#line 158 "markmain.nw"
           done_converting: 
             (void)0;
         }
     }
 }
-#line 543 "markmain.nw"
+#line 542 "markmain.nw"
 if (quoting) {
     errorat(filename, last_open_quote, Warning, "open quote `[[' never closed");
     quoting = 0;
 }
-#line 175 "markmain.nw"
+#line 174 "markmain.nw"
 if (missing_newline) print_pair(out, "nl",0);
-#line 166 "markmain.nw"
+#line 165 "markmain.nw"
 print_state(out, End, state, count);
-#line 96 "markmain.nw"
+#line 95 "markmain.nw"
 }
-#line 552 "markmain.nw"
+#line 551 "markmain.nw"
 main(int argc, char **argv) {
     FILE *fp;
     int i;
@@ -380,7 +380,7 @@ else if (argv[i][2]==0)
     tabsize = 0;                /* no tabs */
 else 
     errormsg(Error, "%s: ill-formed option %s", progname, argv[i]);
-#line 559 "markmain.nw"
+#line 558 "markmain.nw"
                                         break;
             default : errormsg(Error, "%s: unknown option -%c", progname, argv[i][1]);
                       break;
@@ -390,9 +390,10 @@ else
             if (!strcmp(argv[i], "-")) {
                 markup(stdin,stdout,"");
             } else 
-                if ((fp=fopen(argv[i],"r"))==NULL)
+                if ((fp=fopen(argv[i],"r"))==NULL) {
                     errormsg(Error, "%s: couldn't open file %s", progname, argv[i]);
-                else {
+                    fprintf(stdout, "@fatal couldn't open file %s\n", argv[i]);
+                } else {
                     markup(fp,stdout,argv[i]);
                     fclose(fp);
                 }
