@@ -1,6 +1,6 @@
 #line 24 "markup.nw"
-static char rcsid[] = "$Id: markup.nw,v 2.9 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: markup.nw,v 2.21 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -12,11 +12,11 @@ static char rcsname[] = "$Name: v2_9a $";
 
 #line 62 "markup.nw"
 char at_sign = '@';             /* should be the only place '@' is mentioned */
-#line 87 "markup.nw"
+#line 86 "markup.nw"
 static char def_marker[] = " %def ";
 #define def_length (6)
 
-#line 73 "markup.nw"
+#line 72 "markup.nw"
 int starts_doc(char *line) {
     return (*line==at_sign && (line[1]=='\0' || isspace(line[1])));
 }
@@ -25,43 +25,49 @@ char *first_doc_line(char *line) {
     if (line[1]!='\0' && line[1] !='\n') return line+2;
     else return line+1;
 }
-#line 90 "markup.nw"
+#line 89 "markup.nw"
 int is_def(char *line) {
+    int answer;
+    static complained;
     
-#line 99 "markup.nw"
+#line 102 "markup.nw"
 { static int checked = 0;
   if (!checked) {
     assert(strlen(def_marker) == def_length);
     checked = 1;
   }
 }
-#line 92 "markup.nw"
-    return (*line==at_sign && !strncmp(line+1, def_marker, def_length));
+#line 93 "markup.nw"
+    answer = (*line==at_sign && !strncmp(line+1, def_marker, def_length));
+    
+#line 112 "markup.nw"
+if (answer && !complained) {
+    complained = 1;
+/*
+    fprintf(stderr, "Warning: @ %%def is deprecated.  Use `-filter autodefs.xxx'\n"
+	            "         or `-filter btdefn'\n");
+*/
+}
+#line 95 "markup.nw"
+    return answer;
 }
 
 char *remove_def_marker(char *line) {
     return line+1+def_length;
 }
-#line 128 "markup.nw"
+#line 142 "markup.nw"
 char *mod_start(char *s, int mark) {
     return find_escaped(s,"<<","@<<", mark);
 }
 char *mod_end(char *s, int mark) {
     return find_escaped(s,">>","@>>", mark);
 }
-#line 143 "markup.nw"
+#line 161 "markup.nw"
 int starts_code (char *line, char *filename, int lineno) {
     char *tail;
     if (mod_start(line,0) != line+2) return 0;
     tail = mod_end(line+2,0);
-    if (tail == NULL) 
-#line 166 "markup.nw"
-{
-    errorat(filename, lineno, Error, "Module name doesn't end", line);
-    return 0;
-}
-#line 148 "markup.nw"
-    if (*tail++ != '=') return 0;
+    if (tail == NULL || *tail++ != '=') return 0;
     while (isspace(*tail)) tail++;
     return (*tail == '\0');
 }
@@ -72,26 +78,26 @@ void getmodname(char *dest, int size, char *source) {
     char *q = mod_start(p,1);
 
     if (q==NULL) 
-#line 171 "markup.nw"
+#line 182 "markup.nw"
 {
     free(p);
     impossible
         ("I couldn't manage to extract a module name, but I'm sure I saw one");
 }
-#line 159 "markup.nw"
+#line 176 "markup.nw"
     if (mod_end(q,1)==NULL) 
-#line 171 "markup.nw"
+#line 182 "markup.nw"
 {
     free(p);
     impossible
         ("I couldn't manage to extract a module name, but I'm sure I saw one");
 }
-#line 160 "markup.nw"
+#line 177 "markup.nw"
     strncpy(dest,q,size-1);
     dest[size-1] = '\0';
     free(p);
 }
-#line 194 "markup.nw"
+#line 205 "markup.nw"
 char *find_escaped(register char *s, char *search, char *escape, int mark) {
     register char first = *search;
     register char first_escape = (escape != NULL ? *escape : '\0');
