@@ -1,6 +1,6 @@
 #line 9 "mnt.nw"
-static char rcsid[] = "$Id: mnt.nw,v 1.7 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: mnt.nw,v 1.19 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -16,9 +16,9 @@ static char rcsname[] = "$Name: v2_9a $";
 #line 52 "mnt.nw"
 void add_uses_to_usecounts(Module mp);
 void emit_if_unused_and_conforming(Module mp);
-#line 88 "mnt.nw"
+#line 86 "mnt.nw"
 static void emitfile(char *modname);
-#line 183 "mnt.nw"
+#line 180 "mnt.nw"
 #ifdef TEMPNAM
 extern char *tempnam (const char *dir, const char *pfx);        /* temp file in dir */
 #else
@@ -44,7 +44,7 @@ apply_each_module(remove_final_newline);
     for (i=1; i<argc; i++) 
       switch (*argv[i]) {
         case '-': 
-#line 155 "mnt.nw"
+#line 152 "mnt.nw"
     switch (*++argv[i]) {
         case 'a':
             if (strcmp(argv[i], "all"))
@@ -53,7 +53,7 @@ apply_each_module(remove_final_newline);
 #line 49 "mnt.nw"
 apply_each_module(add_uses_to_usecounts);
 apply_each_module(emit_if_unused_and_conforming);
-#line 159 "mnt.nw"
+#line 156 "mnt.nw"
                                                     }
             break;
         case 't': /* set tab size or turn off */
@@ -104,14 +104,14 @@ void emit_if_unused_and_conforming(Module mp) {
             errormsg(Error, "<<%s>> cannot be an output chunk; "
                             "it contains a metacharacter", mp->name);
 }
-#line 90 "mnt.nw"
+#line 88 "mnt.nw"
 static void emitfile(char *modname) { 
   Module root = lookup(modname);
   char *tempname = tempnam(".", 0);
   FILE *fp;
   char *lfmt, *filename;
   
-#line 111 "mnt.nw"
+#line 108 "mnt.nw"
 { int n = strlen(modname) - 1;
   if (n >= 0 && modname[n] == '*') {
     lfmt = locformat;
@@ -122,25 +122,25 @@ static void emitfile(char *modname) {
     filename = modname;
   }
 }
-#line 96 "mnt.nw"
+#line 94 "mnt.nw"
   
-#line 150 "mnt.nw"
+#line 147 "mnt.nw"
 if (root == NULL) {
   errormsg(Error, "Chunk <<%s>> is undefined", filename);
   return;
 }
-#line 97 "mnt.nw"
+#line 95 "mnt.nw"
   fp = fopen(tempname, "w");
   if (fp == NULL) errormsg(Fatal, "Can't open temporary file %s", tempname);
   
-#line 122 "mnt.nw"
+#line 119 "mnt.nw"
 resetloc();
 (void) expand(root, 0, 0, 0, lfmt, fp);
 putc('\n', fp);
 fclose(fp);
-#line 100 "mnt.nw"
+#line 98 "mnt.nw"
   
-#line 128 "mnt.nw"
+#line 125 "mnt.nw"
 { FILE *dest, *tmp;
   dest = fopen(filename, "r");
   if (dest != NULL) {
@@ -159,23 +159,23 @@ fclose(fp);
     }
   }
 }
-#line 101 "mnt.nw"
+#line 99 "mnt.nw"
   remove(filename);
   if (rename(tempname, filename) != 0) { /* different file systems? (may have to copy) */
     FILE *fp = fopen(filename, "w");
     if (fp == NULL) {remove(tempname); 
-#line 147 "mnt.nw"
+#line 144 "mnt.nw"
 errormsg(Error, "Can't open output file %s", filename);
 return;
-#line 104 "mnt.nw"
+#line 102 "mnt.nw"
                                                                                      }
     
-#line 122 "mnt.nw"
+#line 119 "mnt.nw"
 resetloc();
 (void) expand(root, 0, 0, 0, lfmt, fp);
 putc('\n', fp);
 fclose(fp);
-#line 106 "mnt.nw"
+#line 104 "mnt.nw"
     remove(tempname);
   }
 }
