@@ -1,6 +1,6 @@
-#line 52 "modules.nw"
-static char rcsid[] = "$Id: modules.nw,v 2.11 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+#line 50 "modules.nw"
+static char rcsid[] = "$Id: modules.nw,v 2.23 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -11,18 +11,18 @@ static char rcsname[] = "$Name: v2_9a $";
 #include "columns.h"
 #include "strsave.h"
 
-#line 116 "modules.nw"
+#line 110 "modules.nw"
 static struct modpart *
 newmodpart(int type, char *s, Location *loc);   /* create a new module part */
 
 static
 void append(Module mp, struct modpart *p);
-#line 236 "modules.nw"
+#line 227 "modules.nw"
 static int seekcycle(Module mp, Parent parent);
-#line 139 "modules.nw"
+#line 132 "modules.nw"
 static char *lastfilename = 0;
 static int lastlineno = -1;
-#line 42 "modules.nw"
+#line 41 "modules.nw"
 Module newmodule (char *modname) {
     Module p = (Module) malloc (sizeof (struct module));
     checkptr(p);
@@ -31,12 +31,12 @@ Module newmodule (char *modname) {
     p->head = p->tail = NULL;
     return p;
 }
-#line 77 "modules.nw"
+#line 74 "modules.nw"
 void add_part (Module mp, char *s, Parttype type, Location *loc) {
     struct modpart *p = newmodpart(type,s,loc);
     append (mp,p);
 }
-#line 83 "modules.nw"
+#line 79 "modules.nw"
 static struct modpart *
 newmodpart(int type, char *s, Location *loc) {
     struct modpart *p = (struct modpart *) malloc (sizeof (struct modpart));
@@ -45,18 +45,18 @@ newmodpart(int type, char *s, Location *loc) {
     if (s) {
         p->contents = strsave(s);
         
-#line 110 "modules.nw"
+#line 104 "modules.nw"
 { int k = strlen(p->contents)-1;
   if (p->contents[k] == '\n') p->contents[k] = '\0';
   else impossible("input line doesn't end with newline");
 }
-#line 91 "modules.nw"
+#line 87 "modules.nw"
     }
     if (loc) p->loc = *loc;
     p->next = NULL;
     return p;
 }
-#line 98 "modules.nw"
+#line 93 "modules.nw"
 static
 void append(Module mp, struct modpart *p) {
     /* append p to mp's list of modparts */
@@ -67,12 +67,12 @@ void append(Module mp, struct modpart *p) {
         mp->tail = p;
     }
 }
-#line 145 "modules.nw"
+#line 137 "modules.nw"
 void resetloc(void) {
   lastfilename = 0;
   lastlineno = -1;
 }
-#line 153 "modules.nw"
+#line 145 "modules.nw"
 int expand (Module mp, int indent, int partial_distance, Parent parent,  
             char *locformat, FILE *out) {
     struct modpart *p;
@@ -81,22 +81,22 @@ int expand (Module mp, int indent, int partial_distance, Parent parent,
     struct parent thismodule; /* the value only matters when we're expanding a module */
 
     
-#line 228 "modules.nw"
+#line 219 "modules.nw"
 thismodule.this = mp;
 thismodule.parent = parent;
-#line 161 "modules.nw"
+#line 153 "modules.nw"
     
-#line 231 "modules.nw"
+#line 222 "modules.nw"
 if (seekcycle(mp, parent)) {
     errormsg(Error, "<<%s>>", mp->name);
     return Error;
 }
 
-#line 163 "modules.nw"
+#line 155 "modules.nw"
     for (p=mp->head; p!=NULL; p=p->next) {
         switch (p->ptype) {
             case STRING:  
-#line 185 "modules.nw"
+#line 176 "modules.nw"
 if (*(p->contents) != '\0') {
     if (*locformat) {
         if (printloc(out,locformat,p->loc,partial_distance) && (p != mp->head))
@@ -108,10 +108,10 @@ if (*(p->contents) != '\0') {
     fprintf(out,"%s",p->contents);
     partial_distance = limitcolumn(p->contents, partial_distance);
 }
-#line 165 "modules.nw"
+#line 157 "modules.nw"
                                             ;  break;
             case MODULE:  
-#line 210 "modules.nw"
+#line 201 "modules.nw"
 newmod = lookup(p->contents);
 if (newmod==NULL) {
     errormsg (Error, "undefined chunk name: <<%s>>", p->contents);
@@ -128,21 +128,21 @@ if (newmod==NULL) {
 }
 partial_distance = limitcolumn(p->contents, partial_distance + 2) + 2; 
                                 /* account for surrounding brackets */
-#line 166 "modules.nw"
+#line 158 "modules.nw"
                                              ; break;
             case NEWLINE: 
-#line 197 "modules.nw"
+#line 188 "modules.nw"
 partial_distance = 0;
 putc('\n', out);
 lastlineno++;
-#line 167 "modules.nw"
+#line 159 "modules.nw"
                                              ; break;
             default: impossible("bad part type");
         }
     }
     return error;
 }
-#line 238 "modules.nw"
+#line 229 "modules.nw"
 static int seekcycle(Module mp, Parent parent) {
     if (parent == NULL) {
         return 0;
@@ -155,14 +155,14 @@ static int seekcycle(Module mp, Parent parent) {
         return 0;
     }
 }
-#line 260 "modules.nw"
+#line 251 "modules.nw"
 int printloc(FILE *fp, char *fmt, Location loc, int partial) {
     char *p;
     if (*fmt
     && (loc.filename!=lastfilename || lastlineno != loc.lineno)) {
         if (partial) putc('\n',fp);
         
-#line 273 "modules.nw"
+#line 263 "modules.nw"
 for (p = fmt; *p; p++) {
     if (*p == '%') {
         switch (*++p) {
@@ -177,35 +177,35 @@ for (p = fmt; *p; p++) {
                           p += 2;
                         } else
                           
-#line 293 "modules.nw"
+#line 283 "modules.nw"
 { static int complained = 0;
   if (!complained) {
     errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
     complained = 1;
   }
 }
-#line 287 "modules.nw"
+#line 277 "modules.nw"
                       break;            
             default:  
-#line 293 "modules.nw"
+#line 283 "modules.nw"
 { static int complained = 0;
   if (!complained) {
     errormsg(Error,"Bad format sequence ``%%%c'' in -L%s",*p,fmt);
     complained = 1;
   }
 }
-#line 288 "modules.nw"
+#line 278 "modules.nw"
                                                                 break;
         }
     } else putc(*p, fp);
 }
-#line 266 "modules.nw"
+#line 257 "modules.nw"
         lastfilename = loc.filename;
         lastlineno = loc.lineno;
         return 1;
     } else return 0;
 }
-#line 319 "modules.nw"
+#line 309 "modules.nw"
 void remove_final_newline (Module mp) {
         /* remove trailing newline that must be in module */
     if (mp->tail==NULL) /* module has no text */
