@@ -1,6 +1,6 @@
 #line 18 "notangle.nw"
-static char rcsid[] = "$Id: notangle.nw,v 2.10 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: notangle.nw,v 2.22 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #define MAX_MODNAME 255
 #line 23 "notangle.nw"
 #include <stdio.h>
@@ -15,10 +15,10 @@ static char rcsname[] = "$Name: v2_9a $";
 #include "match.h"
 #include "notangle.h"
 
-#line 163 "notangle.nw"
+#line 161 "notangle.nw"
 static void warn_dots(char *modname);          /* warn about names ending in ... */
 
-#line 183 "notangle.nw"
+#line 180 "notangle.nw"
 void insist(char *line, char *keyword, char *msg);
 
 #line 37 "notangle.nw"
@@ -27,7 +27,7 @@ void emit_module_named (FILE *out, char *rootname, char *locformat) {
 
     root = lookup(rootname);
     
-#line 167 "notangle.nw"
+#line 165 "notangle.nw"
 if (root==NULL) {
     errormsg(Fatal, "The root module <<%s>> was not defined.", rootname);
     return;
@@ -36,7 +36,7 @@ if (root==NULL) {
     (void) expand(root,0,0,0,locformat,out);
     putc('\n',out);                     /* make output end with newline */
 }
-#line 57 "notangle.nw"
+#line 56 "notangle.nw"
 void read_defs(FILE *in) {
     char modname[MAX_MODNAME+1] = ""; /* name of module currently being read, 
                                          [[""]] if no module is being read */ 
@@ -47,13 +47,13 @@ void read_defs(FILE *in) {
     while ((line = getline(in)) != NULL) {
         if (is_keyword(line, "fatal")) exit(1);
         
-#line 102 "notangle.nw"
+#line 101 "notangle.nw"
 if (is_keyword(line, "nl") || is_index(line, "nl")) {
     loc.lineno++;
-#line 114 "notangle.nw"
+#line 113 "notangle.nw"
 } else if (is_keyword(line,"file")) {
     
-#line 127 "notangle.nw"
+#line 126 "notangle.nw"
 { char temp[MAX_MODNAME+1];
   if (strlen(line) >= MAX_MODNAME + strlen("@file "))
     overflow("file name size");
@@ -61,44 +61,44 @@ if (is_keyword(line, "nl") || is_index(line, "nl")) {
   temp[strlen(temp)-1]='\0';
   loc.filename = strsave(temp);
 }
-#line 116 "notangle.nw"
+#line 115 "notangle.nw"
     loc.lineno = 1;
 } else if (is_keyword(line, "line")) {
     
-#line 135 "notangle.nw"
+#line 134 "notangle.nw"
 { char temp[MAX_MODNAME+1];
   if (strlen(line) >= MAX_MODNAME + strlen("@line "))
     overflow("file name size");
   strcpy(temp,line+strlen("@line "));
   temp[strlen(temp)-1]='\0';
   
-#line 144 "notangle.nw"
+#line 143 "notangle.nw"
 { char *p;
   for (p = temp; *p; p++)
     if (!isdigit(*p)) 
       errormsg(Error, "non-numeric line number in `@line %s'", temp);
 }
-#line 141 "notangle.nw"
+#line 140 "notangle.nw"
   loc.lineno = atoi(temp);
 }
-#line 119 "notangle.nw"
+#line 118 "notangle.nw"
     loc.lineno--;
-#line 105 "notangle.nw"
+#line 104 "notangle.nw"
 } 
 if (!is_begin(line, "code"))
     continue;
-#line 67 "notangle.nw"
+#line 66 "notangle.nw"
         
-#line 98 "notangle.nw"
+#line 97 "notangle.nw"
 do { line = getline(in);
 } while (line != NULL && !is_keyword(line,"defn") && !is_keyword(line,"text"));
-#line 68 "notangle.nw"
+#line 67 "notangle.nw"
         insist(line,"defn","code chunk had no definition line");
         
-#line 124 "notangle.nw"
+#line 123 "notangle.nw"
 strcpy(modname,line+strlen("@defn "));
 modname[strlen(modname)-1]='\0';
-#line 70 "notangle.nw"
+#line 69 "notangle.nw"
         warn_dots(modname);       /* names ending in ... aren't like web */
         modptr = insert(modname); /* find or add module in table */
 
@@ -118,10 +118,10 @@ modname[strlen(modname)-1]='\0';
             } else if (is_index(line, "nl")) {
                 loc.lineno++;
             
-#line 114 "notangle.nw"
+#line 113 "notangle.nw"
 } else if (is_keyword(line,"file")) {
     
-#line 127 "notangle.nw"
+#line 126 "notangle.nw"
 { char temp[MAX_MODNAME+1];
   if (strlen(line) >= MAX_MODNAME + strlen("@file "))
     overflow("file name size");
@@ -129,59 +129,59 @@ modname[strlen(modname)-1]='\0';
   temp[strlen(temp)-1]='\0';
   loc.filename = strsave(temp);
 }
-#line 116 "notangle.nw"
+#line 115 "notangle.nw"
     loc.lineno = 1;
 } else if (is_keyword(line, "line")) {
     
-#line 135 "notangle.nw"
+#line 134 "notangle.nw"
 { char temp[MAX_MODNAME+1];
   if (strlen(line) >= MAX_MODNAME + strlen("@line "))
     overflow("file name size");
   strcpy(temp,line+strlen("@line "));
   temp[strlen(temp)-1]='\0';
   
-#line 144 "notangle.nw"
+#line 143 "notangle.nw"
 { char *p;
   for (p = temp; *p; p++)
     if (!isdigit(*p)) 
       errormsg(Error, "non-numeric line number in `@line %s'", temp);
 }
-#line 141 "notangle.nw"
+#line 140 "notangle.nw"
   loc.lineno = atoi(temp);
 }
-#line 119 "notangle.nw"
+#line 118 "notangle.nw"
     loc.lineno--;
-#line 89 "notangle.nw"
+#line 88 "notangle.nw"
             } else if (!is_keyword(line, "index"))
                 
-#line 185 "notangle.nw"
+#line 182 "notangle.nw"
 errorat(loc.filename, loc.lineno, Error, "botched code chunk `%s'", line);
-#line 91 "notangle.nw"
+#line 90 "notangle.nw"
             line = getline(in);
         }
         
-#line 179 "notangle.nw"
+#line 176 "notangle.nw"
 if (line==NULL) {
     impossible("End of file occurred in mid-module");
 }
-#line 94 "notangle.nw"
+#line 93 "notangle.nw"
     }
 }
-#line 155 "notangle.nw"
+#line 154 "notangle.nw"
 static
 void warn_dots(char *modname) {
   if (!strcmp(modname+strlen(modname)-3,"...")) 
     errormsg(Warning, "Module name <<%s>> isn't completed as in web", 
              modname);
 }
-#line 172 "notangle.nw"
+#line 170 "notangle.nw"
 void insist(char *line, char *keyword, char *msg) {
   
-#line 179 "notangle.nw"
+#line 176 "notangle.nw"
 if (line==NULL) {
     impossible("End of file occurred in mid-module");
 }
-#line 174 "notangle.nw"
+#line 172 "notangle.nw"
   if (!is_keyword(line,keyword))
     impossible(msg);
 }
