@@ -1,43 +1,42 @@
 #line 24 "recognize.nw"
-static char rcsid[] = "$Id: recognize.nw,v 1.8 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: recognize.nw,v 1.21 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #line 37 "recognize.nw"
 #include <string.h>
-#line 40 "recognize.nw"
 #include <stdlib.h>
-#line 55 "recognize.nw"
-typedef struct recognizer *Recognizer;
-#line 71 "recognize.nw"
-typedef void (*Callback) (void *closure, char *id, char *instance);
 #line 52 "recognize.nw"
+typedef struct recognizer *Recognizer;
+#line 67 "recognize.nw"
+typedef void (*Callback) (void *closure, char *id, char *instance);
+#line 50 "recognize.nw"
 Recognizer new_recognizer(char *alphanum, char *symbols);
-#line 61 "recognize.nw"
+#line 58 "recognize.nw"
 void add_ident(Recognizer r, char *id);
 void stop_adding(Recognizer r);
-#line 65 "recognize.nw"
+#line 61 "recognize.nw"
 void search_for_ident(Recognizer r, char *input, Callback f, void *closure);
-#line 79 "recognize.nw"
+#line 74 "recognize.nw"
 typedef struct goto_node Goto_Node;
 typedef struct move_node Move_Node;
-#line 83 "recognize.nw"
+#line 77 "recognize.nw"
 typedef struct name_node {
   struct name_node *next; /* points to the next name on the output list */
   char *name;
 } Name_Node;
-#line 89 "recognize.nw"
+#line 82 "recognize.nw"
 struct move_node {
   Move_Node *next;      /* points to the next node on the move list */
   Goto_Node *state;     /* the next state for this character */
   unsigned char c;
 };
-#line 96 "recognize.nw"
+#line 88 "recognize.nw"
 struct goto_node {
   Name_Node *output;    /* list of words ending in this state */
   Move_Node *moves;     /* list of possible moves */
   Goto_Node *fail;      /* and where to go when no move fits */
   Goto_Node *next;      /* next goto node with same depth */
 };
-#line 104 "recognize.nw"
+#line 95 "recognize.nw"
 struct recognizer {
   Goto_Node *root[256]; /* might want 128, depending on the character set */
   char *alphas;
@@ -47,17 +46,17 @@ struct recognizer {
                          created while adding ids, used while building
                          the failure functions */
 };
-#line 331 "recognize.nw"
+#line 320 "recognize.nw"
 int reject_match(Recognizer r, char *id, char *input, char *current);
-#line 122 "recognize.nw"
-static Goto_Node *goto_lookup(char c, Goto_Node *g)
+#line 112 "recognize.nw"
+static Goto_Node *goto_lookup(unsigned char c, Goto_Node *g)
 {
   Move_Node *m = g->moves;
   while (m && m->c != c)
     m = m->next;
   return m ? m->state : NULL;
 }
-#line 136 "recognize.nw"
+#line 125 "recognize.nw"
 Recognizer new_recognizer(char *alphanum, char *symbols)
 {
   Recognizer r = (Recognizer) calloc(1, sizeof(struct recognizer));
@@ -67,7 +66,7 @@ Recognizer new_recognizer(char *alphanum, char *symbols)
   r->depths = (Goto_Node **) calloc(r->max_depth, sizeof(Goto_Node *));
   return r;
 }
-#line 152 "recognize.nw"
+#line 140 "recognize.nw"
 void add_ident(Recognizer r, char *id)
 {
   int depth = 2;
@@ -76,20 +75,20 @@ void add_ident(Recognizer r, char *id)
   Goto_Node *q = r->root[c];
   if (!q) 
     
-#line 173 "recognize.nw"
+#line 160 "recognize.nw"
 {
   q = (Goto_Node *) calloc(1, sizeof(Goto_Node));
   r->root[c] = q;
   q->next = r->depths[1];
   r->depths[1] = q;
 }
-#line 160 "recognize.nw"
+#line 148 "recognize.nw"
   c = *p++;
   while (c) {
     Goto_Node *new = goto_lookup(c, q);
     if (!new)
       
-#line 180 "recognize.nw"
+#line 167 "recognize.nw"
 {
   Move_Node *new_move = (Move_Node *) malloc(sizeof(Move_Node));
   new = (Goto_Node *) calloc(1, sizeof(Goto_Node));
@@ -99,7 +98,7 @@ void add_ident(Recognizer r, char *id)
   q->moves = new_move;
   if (depth == r->max_depth)
     
-#line 193 "recognize.nw"
+#line 180 "recognize.nw"
 {
   int i;
   Goto_Node **new_depths = (Goto_Node **) calloc(2*depth, sizeof(Goto_Node *));
@@ -109,17 +108,17 @@ void add_ident(Recognizer r, char *id)
   free(r->depths);
   r->depths = new_depths;
 }
-#line 189 "recognize.nw"
+#line 176 "recognize.nw"
   new->next = r->depths[depth];
   r->depths[depth] = new;
 }
-#line 165 "recognize.nw"
+#line 153 "recognize.nw"
     q = new;
     depth++;
     c = *p++;
   }
   
-#line 203 "recognize.nw"
+#line 190 "recognize.nw"
 if (!q->output) {
   char *copy = malloc(strlen(id) + 1);
   strcpy(copy, id);
@@ -127,9 +126,9 @@ if (!q->output) {
   q->output->next = NULL;
   q->output->name = copy;
 }
-#line 170 "recognize.nw"
+#line 158 "recognize.nw"
 }
-#line 219 "recognize.nw"
+#line 206 "recognize.nw"
 void stop_adding(Recognizer r)
 {
   int depth;
@@ -164,7 +163,7 @@ void stop_adding(Recognizer r)
     }
   }
 }
-#line 259 "recognize.nw"
+#line 245 "recognize.nw"
 void search_for_ident(Recognizer r, char *input, Callback f, void *closure)
 {
   Goto_Node *state = NULL;
@@ -172,15 +171,15 @@ void search_for_ident(Recognizer r, char *input, Callback f, void *closure)
   unsigned char c = (unsigned char) *current++;
   while (c) {
     
-#line 276 "recognize.nw"
+#line 261 "recognize.nw"
 {
   while (state && !goto_lookup(c, state))
     state = state->fail;
   state = state ? goto_lookup(c, state) : r->root[c];
 }
-#line 266 "recognize.nw"
+#line 252 "recognize.nw"
     
-#line 286 "recognize.nw"
+#line 271 "recognize.nw"
 {
   if (state) {
     Name_Node *p = state->output;
@@ -191,11 +190,11 @@ void search_for_ident(Recognizer r, char *input, Callback f, void *closure)
     }
   }
 }
-#line 267 "recognize.nw"
+#line 253 "recognize.nw"
     c = *current++;
   }
 }
-#line 310 "recognize.nw"
+#line 295 "recognize.nw"
 int reject_match(Recognizer r, char *id, char *input, char *current)
 {
   int len = strlen(id);
@@ -206,9 +205,9 @@ int reject_match(Recognizer r, char *id, char *input, char *current)
   current = current - len - 1;
   if (input <= current)
     prev = *current;
-  if (strchr(r->alphas, first) && strchr(r->alphas, prev)) return 1;
-  if (strchr(r->alphas, last ) && strchr(r->alphas, next)) return 1;
-  if (strchr(r->syms,   first) && strchr(r->syms,   prev)) return 1;
-  if (strchr(r->syms,   last ) && strchr(r->syms,   next)) return 1;
+  if (prev && strchr(r->alphas, first) && strchr(r->alphas, prev)) return 1;
+  if (next && strchr(r->alphas, last ) && strchr(r->alphas, next)) return 1;
+  if (prev && strchr(r->syms,   first) && strchr(r->syms,   prev)) return 1;
+  if (next && strchr(r->syms,   last ) && strchr(r->syms,   next)) return 1;
   return 0;
 }
