@@ -1,6 +1,6 @@
 #line 6 "strsave.nw"
-static char rcsid[] = "$Id: strsave.nw,v 2.6 1999/02/16 21:12:14 nr Exp nr $";
-static char rcsname[] = "$Name: v2_9a $";
+static char rcsid[] = "$Id: strsave.nw,v 2.18 2006/06/12 21:03:53 nr Exp nr $";
+static char rcsname[] = "$Name: v2_11b $";
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
